@@ -1,13 +1,13 @@
 import socket, urllib3, json
 global debug
 debug = "off"
-protected = " Protected by: He1Zen, v1.0"
+protected = " Protected by: He1Zen, v1.1"
 
 class server:
     def send(region:str, email:str, *message:str):
         if debug == "on":
             print("[3%] Debug mode ON")
-            print("[7%] Region "+region)
+            print("[7%] Server "+region)
             print("[11%] Starting to get URL")
             print("[20%] Getting json from URL")
         url = "https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json"
